# Install the info files for this package
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/ada-mode.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/autotype.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/ccmode.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/cl.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/ebrowse.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/ediff.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/efaq.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/emacs-mime.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/emacs.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/eshell.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/eudc.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/forms.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/gnus.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/idlwave.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/message.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/mh-e.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/pcl-cvs.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/reftex.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/sc.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/speedbar.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/vip.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/viper.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/widget.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/woman.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/dired-x.gz 2>/dev/null
fi

